@@ -14,11 +14,11 @@ Date::Age - Return an age or age range from date(s)
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 =head1 SYNOPSIS
 
@@ -113,3 +113,7 @@ sub _is_leap {
 1;
 
 __END__
+
+=head1 REPOSITORY
+
+L<https://github.com/nigelhorne/Date-Age>
